@@ -29,9 +29,7 @@
 #include <glade/glade-xml.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <bonobo/bonobo-file-selector-util.h>
+#include <gio/gio.h>
 
 #include "gbf-tree-data.h"
 #include "gbf-project-view.h"
@@ -153,21 +151,18 @@ error_dialog (GtkWindow *parent, const gchar *summary, const gchar *msg, ...)
 {
     va_list ap;
     gchar *tmp;
-    gchar *message;
     GtkWidget *dialog;
     
     va_start (ap, msg);
     tmp = g_strdup_vprintf (msg, ap);
     va_end (ap);
     
-    message = g_markup_printf_escaped ("<b>%s</b>\n\n%s", summary, tmp);
     dialog = gtk_message_dialog_new_with_markup (parent,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
-						 "%s", message);
+						 "<b>%s</b>\n\n%s", summary, tmp);
     g_free (tmp);
-    g_free (message);
     
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
@@ -541,7 +536,7 @@ browse_button_clicked_cb (GtkWidget *widget, gpointer user_data)
 {
     GtkTreeView *tree = user_data;
     gchar *file, *uri;
-    GnomeVFSURI *tmp_uri;
+	GFile *gio_file, *tmp;
     GtkFileChooserDialog* dialog;
 	GtkTreeModel* model;
     GtkTreeIter iter;
@@ -564,13 +559,16 @@ browse_button_clicked_cb (GtkWidget *widget, gpointer user_data)
 				      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				      NULL));
-    tmp_uri = gnome_vfs_uri_new (uri);
+	/* FIXME: this is somewhat UGLY */
+	gio_file = g_file_new_for_uri (uri);
+	tmp = g_file_get_parent (gio_file);
     g_free (uri);
-    uri = NULL;
-    if (tmp_uri) {
-        uri = gnome_vfs_uri_extract_dirname (tmp_uri);
-        gnome_vfs_uri_unref (tmp_uri);
-    }
+	uri = NULL;
+	if (g_file_query_exists (tmp, NULL))
+	{
+	    uri = g_file_get_uri (tmp);
+	}
+
     
     gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog),
     	uri ? uri : g_object_get_data (G_OBJECT (widget), "root"));
