@@ -315,7 +315,8 @@ search_and_replace (void)
 
 	if (SA_FIND_PANE == s->action)
 	{
-		gchar* name = g_strconcat(_("Find: "), s->expr.search_str, NULL);		
+		/* Avoid space in translated string */
+		gchar* name = g_strconcat(_("Find:"), " ", s->expr.search_str, NULL);		
 		AnjutaShell* shell;
 		g_object_get(G_OBJECT(sr->docman), "shell", &shell, NULL);
 		msgman = anjuta_shell_get_interface(shell, 
@@ -446,6 +447,7 @@ search_and_replace (void)
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							g_object_unref (start);
 							g_object_unref (end);
@@ -478,6 +480,7 @@ search_and_replace (void)
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							g_object_unref (start);
 							g_object_unref (end);
@@ -507,6 +510,7 @@ search_and_replace (void)
 								ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 															 start,														 
 															 end,
+															 TRUE,
 															 NULL);
 								ianjuta_editor_selection_replace(IANJUTA_EDITOR_SELECTION (fb->te), 
 																 sr->replace.repl_str,
@@ -542,6 +546,7 @@ search_and_replace (void)
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							ianjuta_editor_selection_replace(IANJUTA_EDITOR_SELECTION (fb->te), 
 															 sr->replace.repl_str,
